@@ -6,7 +6,7 @@ from pathlib import Path
 from PIL.Image import Image
 
 from deepdriver.sdk.chart.chart import Chart
-from deepdriver.sdk.data_types.run import Run
+from deepdriver.sdk.data_types.run import Run, get_run
 from deepdriver.sdk.data_types.table import Table
 from deepdriver.sdk.interface import interface
 from deepdriver.sdk.interface.grpc_interface_pb2 import ArtifactEntry as grpc_ArtifactEntry
@@ -59,7 +59,7 @@ class ArtifactEntry:
         return f"{{path:{self.path},local_path:{self.local_path}}}"
 
 # Artifact 객체에 추가되는 객체는 Image, 일반 파일, 폴더(하위 파일 포함), Table, 소스코드 등이 있다
-class Artifact:
+class Artifacts:
 
     def __init__(self, name: str, type: str, id: int=0, desc: str=None, versioning: str="Y", meta_data: Dict=None, entry_list: List[ArtifactEntry]=None) -> None:
         assert_that(name).is_not_none()
@@ -70,13 +70,14 @@ class Artifact:
         self.id = id
         self.desc = desc
         self.versioning = versioning
+        self.run = get_run()
 
         # 메타정보 (for 모델 or 코드)
         # Ai 학습 모델과 같은 데이터가 아티펙트로 추가될 때 추가정보( 하이퍼파라미터)도 같이 기록되기위한 meta_data 정보
         self.meta_data = meta_data if meta_data else {}
 
         # ArtifactEntry 의 list
-        # Artifact.add() 함수로 데이터가 추가될때마다 리스트에 추가됨
+        # Artifacts.add() 함수로 데이터가 추가될때마다 리스트에 추가됨
         self.entry_list = entry_list if entry_list else []
 
     # 해당 Artifact에 데이터를 추가하는 함수
@@ -117,7 +118,7 @@ class Artifact:
                 self.entry_list.append(ArtifactEntry(path, local_path, size, digest))
 
     # Artifact의 정보를 전송하고, ArtifactEntry 각각의 파일을 전송한다
-    def upload(self, run: Run) -> bool:
+    def upload(self) -> bool:
         # Interface.py의 upoad_artifact ( grpc_interface.py의 upoad_artifact)를 호출 하여 artifact 정보에 대해 전송
         entry_dict = {entry.path: entry for entry in self.entry_list}
         entry_list: List(grpc_ArtifactEntry) = []
@@ -132,7 +133,7 @@ class Artifact:
             ))
             hasher.update(f"{entry_path}:{entry.digest}\n".encode())
         artifact_digest = hasher.hexdigest()
-        id = interface.upload_artifact(run.run_id, self, artifact_digest, run.team_name, run.exp_name, entry_list)
+        id = interface.upload_artifact(self.run.run_id, self, artifact_digest, self.run.team_name, self.run.exp_name, entry_list)
         if id is None:
             return False
         self.id = id
@@ -140,13 +141,13 @@ class Artifact:
         # artifact에 추가된 파일들(ArtifactEntry의 파일)은 각각의 upload함수 호출
         for i, entry in enumerate(self.entry_list):
             # ArtifactEntry.upload() 호출시 인자로서 파일이 저장될 폴더 정보를 넘겨줌
-            root_path = os.path.join(str(run.run_id), "artifact", self.type, self.name)
+            root_path = os.path.join(str(self.run.run_id), "artifact", self.type, self.name)
             last_file_yn = "Y" if i == len(self.entry_list)-1 else "N"
             if self.versioning == "Y":
                 upload_type = "ARTI_REPO"
             else:
                 upload_type = "ARTI_FILES"
-            succeeded = entry.upload(upload_type, root_path, run.run_id, self.id, last_file_yn,  run.team_name, run.exp_name, artifact_digest, entry_list)
+            succeeded = entry.upload(upload_type, root_path, self.run.run_id, self.id, last_file_yn,  self.run.team_name, self.run.exp_name, artifact_digest, entry_list)
             if not succeeded:
                 return False
         return True
